# Key Value Glossary

## Overview

The Key Value Glossary module allows you to use Key / Value fields as glossaries
and automatically highlight terms in content. When a term from the glossary is
found in content, it will be wrapped with a span tag that includes the
definition as a title attribute, creating a tooltip effect.

## Requirements

- Drupal >= 10.4, 11
- [Key Value Field](https://www.drupal.org/project/key_value_field) module

## Installation

1. Install the Key Value Field module if not already installed.
2. Install the Key Value Glossary module.
3. Enable the module via Drush: `drush en key_value_glossary` or through the
Drupal UI.

## Configuration

### Step 1: Create a Key Value Long Field

1. Go to Structure > Content types > [Your content type] > Manage fields
2. Add a new field of type "Key/value (long)"
3. Configure the field as needed

### Step 2: Configure Glossary Fields

1. Go to Configuration > Content > Key Value Glossary
2. Click "Add Glossary Field"
3. Select the entity type, bundle, and field that contains your glossary terms
4. Click Save

### Step 3: Configure Reference Fields

1. Go to Configuration > Content > Key Value Glossary
2. Click "Add Reference Field"
3. Select the entity type, bundle, and entity reference field that will
reference glossary content
4. Click Save

## Usage

1. Create content with your Key / Value field, adding terms and definitions
2. Create content that references the glossary content using the configured
entity reference field
3. When viewing the content, any terms from the glossary that appear in the
content will be automatically highlighted with a tooltip showing the definition

## How It Works

The module:

1. Identifies content with a reference to a glossary
2. Extracts the Key / Value pairs from the glossary's Key / Value field
3. Uses JavaScript to find and wrap occurrences of the keys in the content with
markup meant to display the value.

## Permissions

The module provides the following permission:

- **Administer Key Value Glossary**: Allows users to configure which fields
should be used as glossaries and which fields should be used for referencing
glossaries.

## Troubleshooting

- If terms are not being highlighted, check that the glossary reference field is
properly configured and that the content references a valid glossary.
- Make sure the Key / Value field contains valid key-value pairs.
- Check browser console for any JavaScript errors.
